// Copyright 2020 The gRPC authors.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

syntax = "proto3";

package simple;

import "simpler.proto";

message SimpleMessage {
  string msg = 1;
  oneof personal_or_business {
    bool personal = 2;
    bool business = 3;
  };
  simpler.SimplerMessage simpler_message = 4;
};

message SimpleMessageRequest {
  SimpleMessage simple_msg = 1;
};

message SimpleMessageResponse {
  bool understood = 1;
};

service SimpleMessageService {
  rpc Tell(SimpleMessageRequest) returns (SimpleMessageResponse);
};
